@@ -1,6 +1,6 @@
 <?php
     /*
-     * $Id: setup.php,v 1.2 2003/09/26 19:59:45 indiri69 Exp $
+     * $Id: setup.php,v 1.4 2004/09/24 14:57:31 indiri69 Exp $
      */
     function squirrelmail_plugin_init_get_uuencode() {
         global $squirrelmail_plugin_hooks;
@@ -26,6 +26,6 @@
     }
 
     function get_uuencode_version () {
-        return '2.0';
+        return '3.1-1.4.x';
     }
 ?>
